=======
Credits
=======

Development Lead
----------------

* Micah Johnson  <micah.johnson150@gmail.com>   `@micahjohnson150 <http://github.com/micahjohnson150>`_

Contributors
------------

* Micah Sandusky <micah.sandusky@ars.usda.gov>  `@micah-prime <http://github.com/micah-prime>`_
